@@ -35,7 +35,7 @@ BEGIN
 }
 
 # module/package version
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 # file creation mode (octal, a la chmod)
 $FILEMODE = 0660;
@@ -441,8 +441,14 @@ sub send_ecsmsg_email {
     }
     else {
         # otherwise, send encrypted message
-        $err = send_encrypted_email($node->{encr_typ}, $node->{addr_r},
-                                    $node->{addr}, $subject, @_);
+        $err = send_encrypted_email(
+            $node->{encr_typ},
+            $node->{addr_r},
+            $node->{addr},
+            $node->{encr_out_keyid},
+            $node->{encr_out_passphrase},
+            $subject,
+            @_);
     }
 
     if ( ! $err ) {
@@ -539,6 +545,8 @@ sub send_encrypted_email
     my $encr_typ = shift;
     my $encr_recip = shift;
     my $recipient = shift;
+    my $encr_out_keyid = shift;
+    my $encr_out_passphrase = shift;
     my $subject = shift;
     # @_ now contains message body
 
@@ -564,11 +572,13 @@ sub send_encrypted_email
     my $result = '';
     for ($encr_typ) {
         /PGP2/i and do {
-            $result = pgp2_encrypt($filename, $encr_filename, $encr_recip);
+            $result = pgp2_encrypt($filename, $encr_filename, $encr_recip,
+                $encr_out_keyid, $encr_out_passphrase);
             last;
         };
         /OpenPGP/i and do {
-            $result = openpgp_encrypt($filename, $encr_filename, $encr_recip);
+            $result = openpgp_encrypt($filename, $encr_filename, $encr_recip,
+                $encr_out_keyid, $encr_out_passphrase);
             last;
         };
         $result = "unrecognized encr_typ: $encr_typ";
@@ -632,6 +642,7 @@ sub openpgp_decrypt
     my $input_filename = shift;
     my $output_filename = shift;
     my $required_signature = shift;
+    my $encr_out_passphrase = shift;
 
     # initialize
     return "EMDIS::ECS::openpgp_decrypt(): ECS has not been configured."
@@ -649,7 +660,9 @@ sub openpgp_decrypt
     $ENV{GNUPGHOME} = $cfg->GPG_HOMEDIR;
 
     # attempt to execute command
-    my $result = timelimit_cmd($cfg->T_MSG_PROC, $cmd, $cfg->GPG_PASSPHRASE);
+    my $result = timelimit_cmd($cfg->T_MSG_PROC, $cmd,
+        (defined $encr_out_passphrase and 0 < length $encr_out_passphrase) ?
+            $encr_out_passphrase : $cfg->GPG_PASSPHRASE);
     $result = "EMDIS::ECS::openpgp_decrypt(): $result" if $result;
 
     # check signature, if indicated
@@ -671,6 +684,8 @@ sub openpgp_encrypt
     my $input_filename = shift;
     my $output_filename = shift;
     my $recipient = shift;
+    my $encr_out_keyid = shift;
+    my $encr_out_passphrase = shift;
 
     # initialize
     return "EMDIS::ECS::openpgp_encrypt(): ECS has not been configured."
@@ -678,7 +693,8 @@ sub openpgp_encrypt
     my $cfg = $ECS_CFG;
 
     # compose command
-    my $keyid = $cfg->GPG_KEYID;
+    my $keyid = (defined $encr_out_keyid and 0 < length $encr_out_keyid) ?
+        $encr_out_keyid : $cfg->GPG_KEYID;
     my $cmd = $cfg->OPENPGP_CMD_ENCRYPT;
     $cmd =~ s/__INPUT__/$input_filename/g;
     $cmd =~ s/__OUTPUT__/$output_filename/g;
@@ -691,7 +707,9 @@ sub openpgp_encrypt
     $ENV{GNUPGHOME} = $cfg->GPG_HOMEDIR;
 
     # attempt to execute command
-    my $result = timelimit_cmd($cfg->T_MSG_PROC, $cmd, $cfg->GPG_PASSPHRASE);
+    my $result = timelimit_cmd($cfg->T_MSG_PROC, $cmd,
+        (defined $encr_out_passphrase and 0 < length $encr_out_passphrase) ?
+            $encr_out_passphrase : $cfg->GPG_PASSPHRASE);
     $result = "EMDIS::ECS::openpgp_encrypt(): $result" if $result;
     return $result;
 }
@@ -704,6 +722,7 @@ sub pgp2_decrypt
     my $input_filename = shift;
     my $output_filename = shift;
     my $required_signature = shift;
+    my $encr_out_passphrase = shift;
 
     # initialize
     return "EMDIS::ECS::pgp2_decrypt(): ECS has not been configured."
@@ -719,7 +738,8 @@ sub pgp2_decrypt
 
     # set PGPPATH and PGPPASS environment variables
     $ENV{PGPPATH} = $cfg->PGP_HOMEDIR;
-    $ENV{PGPPASS} = $cfg->PGP_PASSPHRASE;
+    $ENV{PGPPASS} = (defined $encr_out_passphrase and 0 < length $encr_out_passphrase) ?
+        $encr_out_passphrase : $cfg->PGP_PASSPHRASE;
 
     # attempt to execute command
     my $result = timelimit_cmd($cfg->T_MSG_PROC, $cmd);
@@ -745,6 +765,8 @@ sub pgp2_encrypt
     my $input_filename = shift;
     my $output_filename = shift;
     my $recipient = shift;
+    my $encr_out_keyid = shift;
+    my $encr_out_passphrase = shift;
 
     # initialize
     return "EMDIS::ECS::pgp2_encrypt(): ECS has not been configured."
@@ -752,7 +774,8 @@ sub pgp2_encrypt
     my $cfg = $ECS_CFG;
 
     # compose command
-    my $keyid = $cfg->PGP_KEYID;
+    my $keyid = (defined $encr_out_keyid and 0 < length $encr_out_keyid) ?
+        $encr_out_keyid : $cfg->PGP_KEYID;
     my $cmd = $cfg->PGP2_CMD_ENCRYPT;
     $cmd =~ s/__INPUT__/$input_filename/g;
     $cmd =~ s/__OUTPUT__/$output_filename/g;
@@ -763,7 +786,8 @@ sub pgp2_encrypt
 
     # set PGPPATH and PGPPASS environment variables
     $ENV{PGPPATH} = $cfg->PGP_HOMEDIR;
-    $ENV{PGPPASS} = $cfg->PGP_PASSPHRASE;
+    $ENV{PGPPASS} = (defined $encr_out_passphrase and 0 < length $encr_out_passphrase) ?
+        $encr_out_passphrase : $cfg->PGP_PASSPHRASE;
     
     # attempt to execute command
     my $result = timelimit_cmd($cfg->T_MSG_PROC, $cmd);
@@ -1162,6 +1186,17 @@ Email address of administrator for this node.
 Indicates whether meta-messages to/from this node should be encrypted
 ("true" or "false").
 
+=item I<encr_out_keyid>
+
+ID of secret key to be used for encrypted messages to/from this node.
+For this node only, overrides the ECS configuration file's GPG_KEYID or
+PGP_KEYID.
+
+=item I<encr_out_passphrase>
+
+Passphrase for I<encr_out_keyid>.  For this node only, overrides the
+ECS configuration file's GPG_PASSPHRASE or PGP_PASSPHRASE.
+
 =item I<encr_sig>
 
 Identifies the PGP or GnuPG signature for this node.
