@@ -297,7 +297,7 @@ sub _set_defaults
             '--passphrase-fd 0 --quiet --yes --decrypt __INPUT__';
     $this->{PGP2_CMD_ENCRYPT} = '/usr/local/bin/pgp +batchmode +verbose=0 ' .
         '+force +CharSet=latin1 +ArmorLines=0 -o __OUTPUT__ ' .
-            '-eats __INPUT__ __RECIPIENT__ __SELF__';
+            '-u __SELF__ -eats __INPUT__ __RECIPIENT__ __SELF__';
     $this->{PGP2_CMD_DECRYPT} = '/usr/local/bin/pgp +batchmode +verbose=0 ' .
         '+force +CharSet=latin1 -o __OUTPUT__ __INPUT__';
 }
@@ -564,8 +564,8 @@ home directory for GnuPG (defines value for GNUPGHOME environment variable)
 
 =item GPG_KEYID
 
-GnuPG key id for this node, for creating encrypted messages that are
-decryptable by self
+GnuPG key id for this node, for signing encrypted messages and creating
+encrypted messages that are decryptable by self
 
 =item GPG_PASSPHRASE
 
@@ -677,8 +677,8 @@ home directory for PGP (defined value for PGPPATH environment variable)
 
 =item PGP_KEYID
 
-PGP key id for this node, for creating encrypted messages that are
-decryptable by self
+PGP key id for this node, for signing encrypted messages and creating
+encrypted messages that are decryptable by self
 
 =item PGP_PASSPHRASE
 
