@@ -10,8 +10,7 @@ package EMDIS::ECS::FileBackedMessage;
 use EMDIS::ECS qw($ECS_CFG $ECS_NODE_TBL $FILEMODE $VERSION ecs_is_configured
            format_datetime format_msg_filename
            log_debug log_info log_warn log_error log_fatal
-           pgp2_decrypt openpgp_decrypt send_encrypted_email send_email
-           dequote trim);
+           send_encrypted_email send_email dequote trim);
 use Fcntl qw(:DEFAULT :flock);
 use File::Basename;
 use File::Spec::Functions qw(catdir catfile);
@@ -689,8 +688,14 @@ sub send_via_email
             else
             {
                 # send encrypted message
-                $err = send_encrypted_email($node->{encr_typ}, $node->{addr_r},
-                    $node->{addr}, $subject, $all_data);
+                $err = send_encrypted_email(
+                    $node->{encr_typ},
+                    $node->{addr_r},
+                    $node->{addr},
+                    $node->{encr_out_keyid},
+                    $node->{encr_out_passphrase},
+                    $subject,
+                    $all_data);
             }
         }
     }
@@ -748,6 +753,8 @@ sub send_via_email
                         $node->{encr_typ},
                         $node->{addr_r},
                         $node->{addr},
+                        $node->{encr_out_keyid},
+                        $node->{encr_out_passphrase},
                         "$subject:$part_num/$num_parts",
                         $part_data);
                 }
